@@ -80,7 +80,8 @@ class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                             code=self.get_argument('code'))
             # Save the user with e.g. set_secure_cookie
             log.write_logs("6.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-            self.set_secure_cookie("user", user)
+            self.set_secure_cookie("user", user["id_token"])
+            self.redirect("/")
         
 class Userform(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
